from django.apps import AppConfig


class CbvHtmxConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "cbvhtmx"
